@@ -28,9 +28,11 @@ _SCHEMA_CACHE = {}
 _GSETTINGS_SCHEMAS = set(Gio.Settings.list_schemas())
 _GSETTINGS_RELOCATABLE_SCHEMAS = set(Gio.Settings.list_relocatable_schemas())
 
+
 class GSettingsMissingError(Exception):
     pass
 
+
 class _GSettingsSchema:
     def __init__(self, schema_name, schema_dir=None, schema_filename=None, **options):
         if not schema_dir:
@@ -72,19 +74,20 @@ class _GSettingsSchema:
                 if schema_name == schema.getAttribute("id"):
                     for key in schema.getElementsByTagName("key"):
                         name = key.getAttribute("name")
-                        #summary is 'compulsory', description is optional
-                        #... in theory, but we should not barf on bad schemas ever
+                        # summary is 'compulsory', description is optional
+                        # …in theory, but we should not barf on bad schemas ever
                         try:
                             summary = key.getElementsByTagName("summary")[0].childNodes[0].data
                         except:
                             summary = ""
-                            logging.info("Schema missing summary %s (key %s)" % (os.path.basename(schema_path),name))
+                            logging.info("Schema missing summary %s (key %s)" %
+                                         (os.path.basename(schema_path), name))
                         try:
                             description = key.getElementsByTagName("description")[0].childNodes[0].data
                         except:
                             description = ""
 
-                        #if missing translations, use the untranslated values
+                        # if missing translations, use the untranslated values
                         self._schema[name] = dict(
                             summary=translation.gettext(summary) if translation else summary,
                             description=translation.gettext(description) if translation else description
@@ -96,6 +99,7 @@ class _GSettingsSchema:
     def __repr__(self):
         return "<gtweak.gsettings._GSettingsSchema: %s>" % self._schema_name
 
+
 class GSettingsFakeSetting:
     def __init__(self):
         pass
@@ -111,6 +115,7 @@ class GSettingsFakeSetting:
             pass
         return noop
 
+
 class GSettingsSetting(Gio.Settings):
     def __init__(self, schema_name, schema_dir=None, schema_path=None, **options):
 
@@ -146,7 +151,7 @@ class GSettingsSetting(Gio.Settings):
             self.connect("changed", self._on_changed)
 
     def _on_changed(self, settings, key_name):
-        print "Change: %s %s -> %s" % (self.props.schema, key_name, self[key_name])
+        print("Change: %s %s -> %s" % (self.props.schema, key_name, self[key_name]))
 
     def _setting_check_is_list(self, key):
         variant = Gio.Settings.get_value(self, key)
@@ -154,7 +159,7 @@ class GSettingsSetting(Gio.Settings):
 
     def schema_get_summary(self, key):
         return self._schema._schema[key]["summary"]
-        
+
     def schema_get_description(self, key):
         return self._schema._schema[key]["description"]
 
@@ -181,7 +186,7 @@ class GSettingsSetting(Gio.Settings):
             self[key] = vals
             return True
         except ValueError:
-            #not present
+            # not present
             pass
 
     def setting_is_in_list(self, key, value):
@@ -193,7 +198,7 @@ if __name__ == "__main__":
 
     key = "draw-background"
     s = GSettingsSetting("org.gnome.desktop.background")
-    print s.schema_get_summary(key), s.schema_get_description(key)
+    print(s.schema_get_summary(key), s.schema_get_description(key))
 
     key = "disabled-extensions"
     s = GSettingsSetting("org.gnome.shell")
